==> seedsui-react-2.7.9.tgz: package/es/Radio/Radio.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Radio = (_temp = _class = function (_Component) {
  _inherits(Radio, _Component);

  function Radio(props) {
    _classCallCheck(this, Radio);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Radio.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        value = _props.value,
        checked = _props.checked,
        _props$inputAttribute = _props.inputAttribute,
        inputAttribute = _props$inputAttribute === undefined ? {} : _props$inputAttribute,
        caption = _props.caption,
        _props$captionAttribu = _props.captionAttribute,
        captionAttribute = _props$captionAttribu === undefined ? {} : _props$captionAttribu,
        _onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['value', 'checked', 'inputAttribute', 'caption', 'captionAttribute', 'onClick']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { onClick: function onClick(e) {
          _onClick(e, e.target.getAttribute('data-checked') === 'true');
        }, 'data-checked': checked, 'data-value': value, className: 'radio' + (others.className ? ' ' + others.className : '') }),
      React.createElement('span', _extends({}, inputAttribute, { className: 'radio-input' + (inputAttribute.className ? ' ' + inputAttribute.className : '') })),
      caption && React.createElement(
        'span',
        _extends({}, captionAttribute, { className: 'radio-caption' + (captionAttribute.className ? ' ' + captionAttribute.className : '') }),
        caption
      )
    );
  };

  return Radio;
}(Component), _class.defaultProps = {}, _temp);
export { Radio as default };
Radio.propTypes = process.env.NODE_ENV !== "production" ? {
  value: PropTypes.string,
  checked: PropTypes.bool,

  inputAttribute: PropTypes.object,

  caption: PropTypes.string,
  captionAttribute: PropTypes.object,
  onClick: PropTypes.func
} : {};

==> seedsui-react-3.0.4.tgz: package/es/Radio/Radio.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Radio = (_temp = _class = function (_Component) {
  _inherits(Radio, _Component);

  function Radio(props) {
    _classCallCheck(this, Radio);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Radio.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        value = _props.value,
        checked = _props.checked,
        _props$inputAttribute = _props.inputAttribute,
        inputAttribute = _props$inputAttribute === undefined ? {} : _props$inputAttribute,
        caption = _props.caption,
        _props$captionAttribu = _props.captionAttribute,
        captionAttribute = _props$captionAttribu === undefined ? {} : _props$captionAttribu,
        _onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['value', 'checked', 'inputAttribute', 'caption', 'captionAttribute', 'onClick']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { onClick: function onClick(e) {
          if (_onClick) _onClick(e, e.target.getAttribute('data-checked') === 'true');
        }, 'data-checked': checked, 'data-value': value, className: 'radio' + (others.className ? ' ' + others.className : '') }),
      React.createElement('span', _extends({}, inputAttribute, { className: 'radio-input' + (inputAttribute.className ? ' ' + inputAttribute.className : '') })),
      caption && React.createElement(
        'span',
        _extends({}, captionAttribute, { className: 'radio-caption' + (captionAttribute.className ? ' ' + captionAttribute.className : '') }),
        caption
      )
    );
  };

  return Radio;
}(Component), _class.defaultProps = {}, _temp);
export { Radio as default };
Radio.propTypes = process.env.NODE_ENV !== "production" ? {
  value: PropTypes.string,
  checked: PropTypes.bool,

  inputAttribute: PropTypes.object,

  caption: PropTypes.string,
  captionAttribute: PropTypes.object,
  onClick: PropTypes.func
} : {};
